pybtex: A BibTeX-compatible bibliography processor in Python
============================================================

Description
-----------

A BibTeX-compatible bibliography processor in Python

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/pybtex/

